@@ -6,6 +6,9 @@ OC.L10N.register(
     "_%n word_::_%n words_" : ["%n pallabra","%n pallabres"],
     "Delete note" : "Desaniciar nota",
     "Favorite" : "Marcar como favoritu",
-    "No notes found" : "Nun s'alcontraron notes"
+    "No notes found" : "Nun s'alcontraron notes",
+    "*" : "*",
+    "Click here to try again" : "Primi equí pa tentalo de nueves",
+    "Note saved" : "Nota guardada"
 },
 "nplurals=2; plural=(n != 1);");
