@@ -4,6 +4,8 @@ OC.L10N.register(
     "Notes" : "Anotacions",
     "New note" : "Nova anotació",
     "_%n word_::_%n words_" : ["%n paraula","%n paraules"],
+    "An error occurred!" : "S'ha produït un error!",
+    "File error" : "Error al fitxer",
     "Delete note" : "Esborra l\\'anotació",
     "Favorite" : "Preferit",
     "No notes found" : "No s\\'han trobat anotacions"
