@@ -2,9 +2,14 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Noter",
+    "The last viewed note cannot be accessed. " : "Den senest viste note kan ikke tilgås.",
     "New note" : "Ny note",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
     "_%n word_::_%n words_" : ["%n ord","%n ord"],
+    "An error occurred!" : "Der er opstået en fejl!",
+    "File error" : "Fejl i fil",
+    "Encryption Error" : "Fejl i kryptering",
+    "Error" : "Fejl",
     "Delete note" : "Slet note",
     "Favorite" : "Foretrukken",
     "No notes found" : "Ingen noter fundet",
