@@ -5,9 +5,15 @@ OC.L10N.register(
     "New note" : "Νέα σημείωση",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Υπάρχουν επισημάνσεις που δεν έχουν αποθηκευτεί. Αφήνοντας τη σελίδα θα διαγραφούν όλες οι αλλαγές!",
     "_%n word_::_%n words_" : ["%n λέξη","%n λέξεις"],
+    "An error occurred!" : "Παρουσιάστηκε σφάλμα!",
+    "File error" : "Σφάλμα αρχείου",
     "Delete note" : "Διαγραφή σημείωσης",
     "Favorite" : "Αγαπημένο",
     "No notes found" : "Δεν βρέθηκαν σημειώσεις",
-    "The note has unsaved changes." : "Η σημείωση έχει αλλαγές που δεν έχουν σωθεί"
+    "The note has unsaved changes." : "Η σημείωση έχει αλλαγές που δεν έχουν σωθεί",
+    "*" : "*",
+    "Click here to try again" : "Κάντε κλίκ εδώ, για να δοκιμάσετε ξανά.",
+    "Saving failed!" : "Απέτυχε η αποθήκευση!",
+    "Note saved" : "Η σημείωση αποθηκεύτηκε."
 },
 "nplurals=2; plural=(n != 1);");
