@@ -5,9 +5,12 @@ OC.L10N.register(
     "New note" : "Nowa notatka",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Masz niezapisane notatki. Opuszczenie strony spowoduje odrzucenie wszystkich zmian!",
     "_%n word_::_%n words_" : ["%n słowo","%n słowa","%n słów","%n słów"],
+    "Encryption Error" : "Błąd Szyfrowania",
+    "Error" : "Błąd",
     "Delete note" : "Usuń notatkę",
     "Favorite" : "Ulubione",
     "No notes found" : "Nie znaleziono notatek",
+    "Settings" : "Ustawienia",
     "The note has unsaved changes." : "Notatka posiada niezapisane zmiany.",
     "*" : "*",
     "Click here to try again" : "Kliknij tutaj aby spróbować ponownie",
